@@ -27,7 +27,7 @@ PLOTLY_LOGO = "https://images.plot.ly/logo/new-branding/plotly-logomark.png"
 
 def create_profile(filename, search_criteria):
     
-    content = textract.process(filename).decode()
+    content = textract.process(filename, encoding="utf-8").decode()
     content = " ".join(content.split()).lower()
 
     matcher = PhraseMatcher(nlp.vocab)
@@ -35,7 +35,7 @@ def create_profile(filename, search_criteria):
         words = [nlp(word.lower()) for word in search_criteria[col]]
         matcher.add(col, None, *words)
 
-    doc = nlp(content+" sarimax"+ " cnn" + " cnn")
+    doc = nlp(content)
 
     from collections import Counter
     d = []
@@ -65,8 +65,13 @@ def rank(path, search_criteria):
     final_database = pd.DataFrame()
 
     for file_name in files:
-      data = create_profile(os.path.join(path,file_name), search_criteria)
-      final_database = final_database.append(data, ignore_index=True)
+        try:
+            data = create_profile(os.path.join(path,file_name), search_criteria)
+        except:
+            data= "XXXX"
+            continue
+        
+        final_database = final_database.append(data, ignore_index=True)
 
     df = final_database.groupby(['Candidate','Subject']).count().reset_index()
     df = df.pivot_table(values='Count',index='Candidate', columns='Subject').fillna(0).reset_index()
@@ -184,8 +189,7 @@ def run_dash(path, search_criteria, mode=None):
 
     @app.callback([
         Output("table", "columns"),
-        Output("table", "data"),
-        Output('doc_info', 'children')],   
+        Output("table", "data")],   
         [Input("button", "n_clicks")],
     )
     def toggle_navbar_collapse(n):
@@ -222,7 +226,12 @@ class ResumeAnalyzer:
         final_database = pd.DataFrame()
 
         for file_name in files:
-            data = create_profile(os.path.join(self.path,file_name), self.search_criteria)
+            try:
+                data = create_profile(os.path.join(self.path,file_name), self.search_criteria)
+            except:
+                data="XXXX"
+                continue
+                
             final_database = final_database.append(data, ignore_index=True)
 
         df = final_database.groupby(['Candidate','Subject']).count().reset_index()
